@@ -52,7 +52,7 @@ def VacancyAnalysis():
             )
             vacancies = vac_analyzer.run()
             # vacancies es la lista de posiciones
-        elif method == 'ml':
+        elif method == 'ml' or configuracion['geometric_method']==False :
 
             processor = ClusterProcessor(FILE)
             processor.run()
